@@ -655,22 +655,23 @@ class Cursor(object):
            The :meth:`~count` method now supports :meth:`~hint`.
         """
         validate_boolean("with_limit_and_skip", with_limit_and_skip)
-        options = {"query": self.__spec}
+        cmd = SON([("count", self.__collection.name),
+                   ("query", self.__spec)])
         if self.__max_time_ms is not None:
-            options["maxTimeMS"] = self.__max_time_ms
+            cmd["maxTimeMS"] = self.__max_time_ms
         if self.__comment:
-            options["$comment"] = self.__comment
+            cmd["$comment"] = self.__comment
 
         if self.__hint is not None:
-            options["hint"] = self.__hint
+            cmd["hint"] = self.__hint
 
         if with_limit_and_skip:
             if self.__limit:
-                options["limit"] = self.__limit
+                cmd["limit"] = self.__limit
             if self.__skip:
-                options["skip"] = self.__skip
+                cmd["skip"] = self.__skip
 
-        return self.__collection.count(**options)
+        return self.__collection._count(cmd)
 
     def distinct(self, key):
         """Get a list of distinct values for `key` among all documents
@@ -860,6 +861,8 @@ class Cursor(object):
             client._reset_server_and_request_check(self.__address)
             raise
         self.__id = doc["cursor_id"]
+        if self.__id == 0:
+            self.__killed = True
 
         # starting from doesn't get set on getmore's for tailable cursors
         if not self.__query_flags & _QUERY_OPTIONS["tailable_cursor"]:
@@ -934,6 +937,11 @@ class Cursor(object):
         <http://www.mongodb.org/display/DOCS/Tailable+Cursors>`_
         since they will stop iterating even though they *may* return more
         results in the future.
+
+        With regular cursors, simply use a for loop instead of :attr:`alive`::
+
+            for doc in collection.find():
+                print(doc)
         """
         return bool(len(self.__data) or (not self.__killed))
 
